@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Alexander Larsson <alexl@redhat.com>
  * Author: Tor Lillqvist <tml@iki.fi>
@@ -65,13 +63,18 @@ struct _GWin32InputStreamClass
   void (*_g_reserved5) (void);
 };
 
+GLIB_AVAILABLE_IN_ALL
 GType          g_win32_input_stream_get_type         (void) G_GNUC_CONST;
 
+GLIB_AVAILABLE_IN_ALL
 GInputStream * g_win32_input_stream_new              (void              *handle,
 						      gboolean           close_handle);
+GLIB_AVAILABLE_IN_ALL
 void           g_win32_input_stream_set_close_handle (GWin32InputStream *stream,
 						      gboolean           close_handle);
+GLIB_AVAILABLE_IN_ALL
 gboolean       g_win32_input_stream_get_close_handle (GWin32InputStream *stream);
+GLIB_AVAILABLE_IN_ALL
 void          *g_win32_input_stream_get_handle       (GWin32InputStream *stream);
 
 G_END_DECLS
